about summary refs log tree commit diff
path: root/compiler/rustc_feature/src
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2023-01-13 05:04:48 +0000
committerbors <bors@rust-lang.org>2023-01-13 05:04:48 +0000
commit279f1c9d8c26a8d227ae8ab806d262bb784b251b (patch)
tree5df99150626d3bf61de660e12ab81cbc70bc009c /compiler/rustc_feature/src
parentbfffe406fbcabb37b95779f2d252c4a277191e0d (diff)
parent42a50bac319c0fc4fedf295fb1e606f015c48bb6 (diff)
downloadrust-279f1c9d8c26a8d227ae8ab806d262bb784b251b.tar.gz
rust-279f1c9d8c26a8d227ae8ab806d262bb784b251b.zip
Auto merge of #106004 - fee1-dead-contrib:const-closures, r=oli-obk
Const closures

cc https://github.com/rust-lang/rust/issues/106003
Diffstat (limited to 'compiler/rustc_feature/src')
-rw-r--r--compiler/rustc_feature/src/active.rs4
1 files changed, 3 insertions, 1 deletions
diff --git a/compiler/rustc_feature/src/active.rs b/compiler/rustc_feature/src/active.rs
index 531ddcc1fa6..196c31302a0 100644
--- a/compiler/rustc_feature/src/active.rs
+++ b/compiler/rustc_feature/src/active.rs
@@ -339,7 +339,9 @@ declare_features! (
     (active, collapse_debuginfo, "1.65.0", Some(100758), None),
     /// Allows `async {}` expressions in const contexts.
     (active, const_async_blocks, "1.53.0", Some(85368), None),
-    // Allows limiting the evaluation steps of const expressions
+    /// Allows `const || {}` closures in const contexts.
+    (incomplete, const_closures, "CURRENT_RUSTC_VERSION", Some(106003), None),
+    /// Allows limiting the evaluation steps of const expressions
     (active, const_eval_limit, "1.43.0", Some(67217), None),
     /// Allows the definition of `const extern fn` and `const unsafe extern fn`.
     (active, const_extern_fn, "1.40.0", Some(64926), None),